##Wire-tailed Manakin Telomere Analysis
#October 28, 2020
#Ben Vernasco

library(dplyr)
library(ggplot2)
library(lmerTest)
library(lubridate)
library(visreg)
library(r2glmm)
library(cowplot)
setwd(".../Code and Data")
DF<-read.csv("PIPFIL.Telo.Data.csv")
levels(DF$TH.FL)<-c("Floater","Territory-holder")
DF$Field.Season<-as.factor(DF$Field.Season)
DF$Count<-rep(1,nrow(DF))

####Code for repeatability Analysis and repeatability estimate graphs

#Function for calculating repeatability
myfun.lmer <- function(mod, group){
  tab <- data.frame(VarCorr(mod))[,c('grp','vcov')]
  return(tab$vcov[tab$grp=='Band.Num']/sum(tab$vcov))
}

#Overall Repeatability

mod <- lmer(rTL ~ 1 + (1|Band.Num), data=DF)
T.rep.sim <- bootMer(mod, myfun.lmer, nsim=1000)$t # parametric bootstrap to get boostrapped CIs, takes longer the more nsim you do
overall<-myfun.lmer(mod)
overall.CIs<-quantile(T.rep.sim, c(0.025,0.975))
overall<-c(0.73,0.61,0.81)

#TH only
mod <- lmer(rTL ~ 1 + (1|Band.Num), data=filter(DF, TH.FL == "Territory-holder"))
T.rep.sim <- bootMer(mod, myfun.lmer, nsim=1000)$t # parametric bootstrap to get boostrapped CIs, takes longer the more nsim you do
TH.rep<-myfun.lmer(mod)
TH.CIs<-quantile(T.rep.sim, c(0.025,0.975))
TH<-c(0.84,0.70,0.91)

#FL only
mod <- lmer(rTL ~ 1 + (1|Band.Num), data=filter(DF, TH.FL != "Territory-holder"))
T.rep.sim <- bootMer(mod, myfun.lmer, nsim=1000)$t # parametric bootstrap to get boostrapped CIs, takes longer the more nsim you do
FL.rep<-myfun.lmer(mod)
FL.CIs<-quantile(T.rep.sim, c(0.025,0.975))
FL<-c(0.69,0.51,0.81)

#Longterm
mod <- lmer(rTL ~ 1 + (1|Band.Num), data=filter(DF, longest.term == 1))
LT.rep<-myfun.lmer(mod)
T.rep.sim <- bootMer(mod, myfun.lmer, nsim=1000)$t
LT.CIs<-quantile(T.rep.sim, c(0.025,0.975))
LT<-c(0.72,0.56,0.83)
#Short term
mod <- lmer(rTL ~ 1 + (1|Band.Num), data=filter(DF, short.term == 1))
ST.rep<-myfun.lmer(mod)
T.rep.sim <- bootMer(mod, myfun.lmer, nsim=1000)$t
ST.CIs<-quantile(T.rep.sim, c(0.025,0.975))
ST<-c(0.86,0.72,0.93)

#Full repeatability dataset
overall<-c(0.73,0.61,0.81)
TH<-c(0.84,0.70,0.91)
FL<-c(0.69,0.51,0.81)
LT<-c(0.72,0.56,0.83)
ST<-c(0.86,0.72,0.93)

aa<-as.data.frame(rbind(overall,TH,FL,LT,ST))
colnames(aa)<-c("Repeatability","lower.CI","upper.CI")
aa$type<-c("Overall","Territory-holder","Floater","Long Term","Short Term")
aa$type<-factor(aa$type,levels = c("Overall","Floater","Territory-holder","Short Term","Long Term"))
aa$facet<-c("Overall", "Social Status","Social Status","Sampling Interval", "Sampling Interval")
hline.data <- data.frame(z = c(0.84,0.86), facet = c("Social Status","Sampling Interval")) 

ggplot(aa)+
  aes(x = type, y = Repeatability)+
  geom_point(size = 3)+
  geom_errorbar(aes(ymin = lower.CI, ymax = upper.CI), width = 0.1)+
  theme_bw(base_size = 15)+
  facet_grid(.~facet, scales = "free", space="free_x")+
  xlab("")+
  ylim(0,1)+
  ylab("Repeatability Estimate")+
  geom_hline(aes(yintercept = z), hline.data, linetype = "dashed")+
  theme(panel.grid.major = element_blank(),
        panel.grid.minor = element_blank())

####Analyzing the relationship between male behavior and telomere length
DF2<-arrange(DF,degree)
DF2<-DF2[-c(87:210),]
DF2$strength<-log(DF2$strength+1)
DF2$degree<-log(DF2$degree+1)
DF2$effort<-log(DF2$effort+1)
DF3<-arrange(DF,import)
DF3<-DF3[-c(87:210),]
#Function for building AIC table
aictable<-function(X,m){
  #
  #  This function will create a full model selection table based on AICc.
  #  
  #  Inputs:
  #
  #  X is the AIC table produced by R by using AIC(model1,model2, ...)
  #  m is the sample size
  #
  #
  rnames<-row.names(X)
  AICc<-X$AIC+2*X$df*(X$df+1)/(m-X$df-1)     #small-sample correction
  logL<-X$df-X$AIC/2                         #Log-likelihood
  tab<-data.frame(X[,1],logL,AICc)           #Remove AIC column; add logL and AICc
  colnames(tab)[1]<-c("Params")              #Rename "df" column   
  row.names(tab)<-rnames
  tab<-tab[order(tab$AICc),]                 #Sort by ascending AICc value
  deltaAICc<-tab$AICc-min(tab$AICc)          #Delta AICc
  weight<-exp(-deltaAICc/2)/sum(exp(-deltaAICc/2))  #Weights
  cumwt<-weight                              #Column for cumulative weight
  for(i in 2:dim(X)[1]){                  
    cumwt[i]<-cumwt[i-1]+cumwt[i]              #Accumulate weight from the top
  }
  tab<-data.frame(tab,deltaAICc,weight,cumwt)
  tab<-round(tab,4)
  tab
}

#Degree
summary(lm8<-lmer(degree~rTL+Age.at.Cap2+Field.Season+(1|Band.Num), data = DF2))
summary(lm9<-lmer(degree~rTL+Field.Season+(1|Band.Num), data = DF2))
summary(lm12<-lmer(degree~Age.at.Cap2+Field.Season+(1|Band.Num), data = DF2))
summary(lm14<-lmer(degree~Field.Season+(1|Band.Num), data = DF2))

X<-AIC(lm8,lm9,lm12,lm14)
m<-86
deg<-aictable(X,m)

#Strength

summary(lm8<-lmer(strength~rTL+Age.at.Cap2+Field.Season+(1|Band.Num), data = DF2))
summary(lm9<-lmer(strength~rTL+Field.Season+(1|Band.Num), data = DF2))
summary(lm12<-lmer(strength~Age.at.Cap2+Field.Season+(1|Band.Num), data = DF2))
summary(lm14<-lmer(strength~Field.Season+(1|Band.Num), data = DF2))

X<-AIC(lm8,lm9,lm12,lm14)
m<-86

str<-aictable(X,m)

#Effort

summary(lm8<-lmer(effort~rTL+Age.at.Cap2+Field.Season+(1|Band.Num), data = DF2))
summary(lm9<-lmer(effort~rTL+Field.Season+(1|Band.Num), data = DF2))
summary(lm12<-lmer(effort~Age.at.Cap2+Field.Season+(1|Band.Num), data = DF2))
summary(lm14<-lmer(effort~Field.Season+(1|Band.Num), data = DF2))

X<-AIC(lm8,lm9,lm12,lm14)
m<-86

eff<-aictable(X,m)

#Importance

summary(lm8<-lmer(import~rTL+Age.at.Cap2+Field.Season+(1|Band.Num), data = DF3))
summary(lm9<-lmer(import~rTL+Field.Season+(1|Band.Num), data = DF3))
summary(lm12<-lmer(import~Age.at.Cap2+Field.Season+(1|Band.Num), data = DF3))
summary(lm14<-lmer(import~Field.Season+(1|Band.Num), data = DF3))

X<-AIC(lm8,lm9,lm12,lm14)
m<-86

imp<-aictable(X,m)

#Calculating R2-GLMM

summary(lmdeg<-lmer(degree~rTL+Field.Season+(1|Band.Num), data = DF2))
summary(lmstr<-lmer(strength~rTL+Field.Season+(1|Band.Num), data = DF2)) #1
summary(lmeff<-lmer(effort~Age.at.Cap2+Field.Season+(1|Band.Num), data = DF2))  #3
summary(lmimp<-lmer(import~rTL+Field.Season+(1|Band.Num), data = DF2))

str<-as.data.frame(r2beta(lmstr))[3,]
deg<-as.data.frame(r2beta(lmdeg))[3,]
eff<-as.data.frame(r2beta(lmeff))[2,]
imp<-as.data.frame(r2beta(lmimp))[3,]
c<-c("str","deg","eff","imp")
mutate(rbind(str,deg,eff,imp),behav = c)

##Graphing telomere length-behvaior relationships
summary(lmdeg<-lmer(degree~rTL+Field.Season+(1|Band.Num), data = DF2))
summary(lmstr<-lmer(strength~rTL+Field.Season+(1|Band.Num), data = DF2)) #1
summary(lmeff<-lmer(effort~Age.at.Cap2+Field.Season+(1|Band.Num), data = DF2))  #3
summary(lmimp<-lmer(import~rTL+Field.Season+(1|Band.Num), data = DF2))

ad<-ggplot(DF2)+
  aes(x = rTL, y = effort)+
  geom_point(alpha = 0.6, size = 3, aes(color = TH.FL, shape = TH.FL))+
  theme_classic(base_size = 14)+
  xlab("Relative Telomere Length")+
  ylab("Effort")+
  ylim(0,8)+
  theme(legend.position = "none")+
  scale_color_manual(values = c("red","black"))

b<-visreg(lmimp, "rTL", scale = "response")
bbb<-b$fit
DF3$part.res<-b$res[,5]
ae<-ggplot(bbb)+
  aes(x = rTL, y = visregFit)+
  geom_point(aes(x = rTL, y = part.res, color = TH.FL, shape = TH.FL), alpha = 0.6, size = 3, data = DF3[-c(27,2,18),])+
  geom_line(size = 1)+
  theme_classic(base_size = 14)+
  xlab("Relative Telomere Length")+
  ylab("Importance")+
  xlim(0.7,1.8)+
  ylim(-0.1,.8)+
  theme(legend.position = "top", legend.title = element_blank(), legend.direction = "horizontal")+
  scale_color_manual(values = c("red","black"))

b<-visreg(lmstr, "rTL", scale = "response")
bbb<-b$fit
DF2$part.res<-b$res[,5]
ac<-ggplot(bbb)+
  aes(x = rTL, y = visregFit)+
  geom_point(aes(x = rTL, y = part.res, color = TH.FL, shape = TH.FL), alpha = 0.6, size = 3, data = DF2)+
  geom_line(size = 1)+
  theme_classic(base_size = 14)+
  xlab("Relative Telomere Length")+
  ylab("Strength")+
  xlim(0.6, 1.75)+
  ylim(0.5,5)+
  theme(legend.position = "none")+
  scale_color_manual(values = c("red","black"))


b<-visreg(lmdeg, "rTL", scale = "response")
bbb<-b$fit
DF2$part.res<-b$res[,5]

ab<-ggplot(bbb)+
  aes(x = rTL, y = visregFit)+
  geom_point(aes(x = rTL, y = degree, color = TH.FL, shape = TH.FL), alpha = 0.6, size = 3, data = DF2)+
  #geom_line(size = 1)+
  theme_classic(base_size = 14)+
  xlab("Relative Telomere Length")+
  ylab("Degree")+
  xlim(0.6, 1.75)+
  ylim(0,2.5)+
  theme(legend.position = "none")+
  scale_color_manual(values = c("red","black"))

plot_grid(ad,ab,ac,ae, labels = c("A)", "B)", "C)", "D)"), scale =  0.9, label_size = 12, label_fontface = "plain")

####Telomere Dynamics Analysis

df<-filter(DF, within.between != "")
df<-arrange(df,degree)
df<-df[c(1:63),]
df$strength<-log(df$strength+1)
df$effort<-log(df$effort+1)
df$degree<-log(df$degree+1)


summary(lm1<-lm(D~import+within.between, data = df))
summary(lm2<-lm(D~effort+within.between, data = df))
summary(lm3<-lm(D~strength+within.between, data = df))
summary(lm4<-lm(D~degree+within.between, data = df))
summary(lm5<-lm(D~import+within.between+Field.Season, data = df))
summary(lm6<-lm(D~effort+within.between+Field.Season, data = df))
summary(lm7<-lm(D~strength+within.between+Field.Season, data = df))
summary(lm8<-lm(D~degree+within.between+Field.Season, data = df))
summary(lm9<-lm(D~import+within.between+TH.FL, data = df))
summary(lm10<-lm(D~effort+within.between+TH.FL, data = df))
summary(lm11<-lm(D~strength+within.between+TH.FL, data = df))
summary(lm12<-lm(D~degree+within.between+TH.FL, data = df))
summary(lm13<-lm(D~import*TH.FL+within.between, data = df))
summary(lm14<-lm(D~effort*TH.FL+within.between, data = df))
summary(lm15<-lm(D~strength*TH.FL+within.between, data = df))
summary(lm16<-lm(D~degree*TH.FL+within.between, data = df))
summary(lm17<-lm(D~import+within.between+TH.FL+Field.Season, data = df))
summary(lm18<-lm(D~effort+within.between+TH.FL+Field.Season, data = df))
summary(lm19<-lm(D~strength+within.between+TH.FL+Field.Season, data = df))
summary(lm20<-lm(D~degree+within.between+TH.FL+Field.Season, data = df))
summary(lm21<-lm(D~import*TH.FL+within.between+Field.Season, data = df))
summary(lm22<-lm(D~effort*TH.FL+within.between+Field.Season, data = df))
summary(lm23<-lm(D~strength*TH.FL+within.between+Field.Season, data = df))
summary(lm24<-lm(D~degree*TH.FL+within.between+Field.Season, data = df))
summary(lm25<-lm(D~within.between+Field.Season, data = df))
summary(lm26<-lm(D~within.between, data = df))
summary(lm27<-lm(D~import+within.between+rTL, data = df))
summary(lm30<-lm(D~effort+within.between+rTL, data = df))
summary(lm31<-lm(D~strength+within.between+rTL, data = df))
summary(lm32<-lm(D~degree+within.between+rTL, data = df))
summary(lm33<-lm(D~import+within.between+Field.Season+rTL, data = df))
summary(lm34<-lm(D~effort+within.between+Field.Season+rTL, data = df))
summary(lm35<-lm(D~strength+within.between+Field.Season+rTL, data = df))
summary(lm36<-lm(D~degree+within.between+Field.Season+rTL, data = df))
summary(lm37<-lm(D~import+within.between+TH.FL+rTL, data = df))
summary(lm38<-lm(D~effort+within.between+TH.FL+rTL, data = df))
summary(lm39<-lm(D~strength+within.between+TH.FL+rTL, data = df))
summary(lm40<-lm(D~degree+within.between+TH.FL+rTL, data = df))
summary(lm41<-lm(D~import*TH.FL+within.between+rTL, data = df))
summary(lm42<-lm(D~effort*TH.FL+within.between+rTL, data = df))
summary(lm43<-lm(D~strength*TH.FL+within.between+rTL, data = df))
summary(lm44<-lm(D~degree*TH.FL+within.between+rTL, data = df))
summary(lm45<-lm(D~import+within.between+TH.FL+Field.Season+rTL, data = df))
summary(lm46<-lm(D~effort+within.between+TH.FL+Field.Season+rTL, data = df))
summary(lm47<-lm(D~strength+within.between+TH.FL+Field.Season+rTL, data = df))
summary(lm48<-lm(D~degree+within.between+TH.FL+Field.Season+rTL, data = df))
summary(lm49<-lm(D~import*TH.FL+within.between+Field.Season+rTL, data = df))
summary(lm50<-lm(D~effort*TH.FL+within.between+Field.Season+rTL, data = df))
summary(lm51<-lm(D~strength*TH.FL+within.between+Field.Season+rTL, data = df))
summary(lm52<-lm(D~degree*TH.FL+within.between+Field.Season+rTL, data = df))
summary(lm53<-lm(D~within.between+Field.Season+rTL, data = df))
summary(lm54<-lm(D~within.between+rTL, data = df))


X<-AIC(lm1,lm2,lm3,lm4,lm5,lm6,lm7,lm8,lm9,lm10,lm11,lm12,
       lm13,lm14,lm15,lm16,lm17,lm18,lm19,lm20,lm21,lm22,
       lm23,lm24,lm25,lm26,lm27,lm30,lm31,lm32,
       lm33,lm34,lm35,lm36,lm37,lm38,lm39,lm40,lm41,lm42,
       lm43,lm44,lm45,lm46,lm47,lm48,lm49,lm50,lm51,lm52,lm53,lm54)
m<-63

a<-aictable(X,m)

#Graphing relationship

b<-visreg(lm4, "degree", scale = "response")
bbb<-b$fit
df$part.res<-b$res[,4]

ggplot(bbb)+
  aes(x = degree, y = visregFit)+
  geom_ribbon(aes(ymin = visregLwr, ymax = visregUpr, x = degree), alpha = 0.4)+
  geom_point(aes(x = degree, y = part.res, color = TH.FL, shape = TH.FL), alpha = 0.5, size = 2,data = df)+
  geom_line(size = 1)+
  theme_classic(base_size = 12)+
  ylab("Change in Relative Telomere Length (D)")+
  xlab("Degree")+
  theme(legend.position = c(0.82,0.12), legend.title = element_blank())+
  scale_color_manual(values = c("red","black"))

#### Testing for within- and between-individual age-related changes in telomere lengths

#Full dataset

summary(lm1<-lmer(rTL~Avg.Age+Delta.Age+(1|Band.Num), data = DF))
summary(lm2<-lmer(rTL~Avg.Age+Age.at.Cap2+(1|Band.Num), data = DF))

#Floaters Only

summary(lm1<-lmer(rTL~Avg.Age+Delta.Age+(1|Band.Num), data = filter(DF, TH.FL != "Territory-holder")))
summary(lm1b<-lmer(rTL~Avg.Age+Age.at.Cap2+(1|Band.Num), data = filter(DF, TH.FL != "Territory-holder")))

#Territory-holders only

summary(lm1<-lmer(rTL~Avg.Age+Delta.Age+(1|Band.Num), data = filter(DF, TH.FL == "Territory-holder")))
summary(lm1b<-lmer(rTL~Avg.Age+Age.at.Cap2+(1|Band.Num), data = filter(DF, TH.FL == "Territory-holder")))


####Testing for telomere elongation that exceeds residual error in TL
#Code adapted from the SimonsTest.R file in the Data and Code of: Spurgin, L.G., Bebbington, K., Fairfield, E.A., Hammers, M., Komdeur, J., Burke, T., Dugdale, H.L., Richardson, D.S., 2018. Spatio-temporal variation in lifelong telomere dynamics in a long-term ecological study. J. Anim. Ecol. 87, 187–198. doi:10.1111/1365-2656.12741

df<-read.csv("rTL.long.format.csv")
x<-na.omit(df$rTL4)
a<-c(na.action(x))
DF<-df[-a,]
data<-DF[,c(2:5)]

matrixresi<-matrix(0,dim(data)[1],1)  # a matrix to put the residuals of the individual regressions in in
x=1:dim(data)[2] #number of columns is the number of timepoints
j=1
while(j<(dim(data)[1]+1)) #loop the individual regressions for the amount of individuals in the dataset
{
  fit<-lm(t(data[j,])~x)  #individual linear regression
  matrixresi[j,]<-sum((residuals(fit))^2)/(length(x)-2) #residual sum of squares
  j<-j+1
}
sigma1<-mean(c(matrixresi)) #average residual sum of squares across the individuals


#Estimating error under the assumption that TL cannot increase over time, Equation 5 in main manuscript

#first we calculate the increases TL increases over time 
deltaTL=data[,3]-data[,1]

#Next we determine which individuals increase in TL between the first and last timepoint
indexTLincreases=which(deltaTL>0)

#We create a new variable including only the data of individual increases
TLincreases=deltaTL[indexTLincreases]
#sigma2
sigma2=0.5*sum(TLincreases^2)/(length(TLincreases))


#compare both estimates of error variance (sigma1 and sigma2), Equation 6 in main manuscript
vratio=sigma2/sigma1
pvalue<-pf(vratio,length(TLincreases)-1,dim(data)[1]-1,lower.tail=F)
print(pvalue)


#designating a set of individuals who show TL increases with a set confidence interval, e.g. 97.5%, equation 7.
upperlimit<-((dim(data)[1]-1)*sigma1)/qchisq(0.025,(dim(data)[1]-1)) #Note, change 0.025 in the qchisq to change the confidence at which individual increases are determined. This upperlimit is the upper confidence of the variance determined by the individual regressions. This variance is the variance of the upper confidence limit of the underlying normally distributed error function. Using this we can look up individual TL increases that are at the boundary (with 95% confidence) of this normal distribution (with standard deviation equal to the upper confidence of sqrt(sigma1)
upperTL=qnorm(0.05,0,sd=sqrt(upperlimit),lower.tail=F)
outsideconfindex=which((0.5*TLincreases)>upperTL)  #because TL increases are a result from the addition of two equal error distributions divide by 2 (i.e. *0.5).
print(indexTLincreases[outsideconfindex]) #initial row of individual in the dataset that shows TL increase beyond the set confidence interval


